@@ -27,6 +27,7 @@ function(X,
 	 keepX = rep(ncol(X), ncomp),
          max.iter = 500,		 
          tol = 1e-06,
+         near.zero.var = TRUE,
          ...)
 {
     X = as.matrix(X)
@@ -62,6 +63,7 @@ function(X,
 	 
     result$ind.mat = ind.mat
     result$names$Y = levels(Y)
+    result$near.zero.var = near.zero.var
     class(result) = "splsda"
     return(invisible(result))	
 }
